/**
 * vue-inertia-composable
 *
 * @description Inertia for Vue2 Composition API.
 * @author Logue <logue@hotmail.co.jp>
 * @copyright 2022-2023 By Masashi Yoshikawa All rights reserved.
 * @license MIT
 * @version 0.4.2
 * @see {@link https://github.com/logue/vue-inertia-composable}
 */

import { defineComponent, h, getCurrentInstance } from 'vue-demi';
import ziggy from 'ziggy-js';
import { usePage as usePage$1, useForm as useForm$1 } from '@inertiajs/vue2';
import { mergeDataIntoQueryString, shouldIntercept, Inertia } from '@inertiajs/inertia';

const InertiaLink = defineComponent({
  name: "InertiaLink",
  props: {
    as: {
      type: String,
      default: "a"
    },
    href: {
      type: String,
      default: ""
    },
    method: {
      type: String,
      default: "get"
    },
    data: {
      type: Object,
      default: () => {
      }
    },
    replace: {
      type: Boolean,
      default: false
    },
    preserveScroll: {
      type: Boolean,
      default: false
    },
    preserveState: {
      type: Boolean,
      default: false
    },
    only: {
      type: Array,
      default: () => []
    },
    headers: {
      type: Object,
      default: () => {
      }
    },
    errorBag: {
      type: String,
      default: null
    },
    forceFormData: {
      type: Boolean,
      default: false
    },
    queryStringArrayFormat: {
      type: String,
      default: "brackets"
    }
  },
  render() {
    const as = this.$props.as.toLowerCase() || "a";
    const method = this.$props.method.toLocaleLowerCase() || "get";
    const attrs = this.$attrs;
    const [href, data] = mergeDataIntoQueryString(
      method,
      this.$props.href || "",
      this.$props.data,
      this.$props.queryStringArrayFormat
    );
    if (as === "a" && method !== "get") {
      console.warn(
        `Creating POST/PUT/PATCH/DELETE <a> links is discouraged as it causes "Open Link in New Tab/Window" accessibility issues.

Please specify a more appropriate element using the "as" attribute. For example:

<inertia-link href="${href}" method="${method}" as="button">...</inertia-link>`
      );
    }
    return h(
      as,
      {
        ...this.$attrs,
        ...as === "a" ? { href } : {},
        onClick: (event) => {
          event.preventDefault();
          if (!shouldIntercept(event)) {
            return;
          }
          Inertia.visit(href, {
            method,
            data,
            replace: this.$props.replace,
            preserveScroll: this.$props.preserveScroll,
            preserveState: this.$props.preserveState ?? method !== "get",
            only: this.$props.only,
            headers: this.$props.headers,
            errorBag: this.$props.errorBag,
            forceFormData: this.$props.forceFormData,
            onCancelToken: attrs.onCancelToken || (() => void 0),
            onBefore: attrs.onBefore || (() => void 0),
            onStart: attrs.onStart || (() => void 0),
            onProgress: attrs.onProgress || (() => void 0),
            onFinish: attrs.onFinish || (() => void 0),
            onCancel: attrs.onCancel || (() => void 0),
            onSuccess: attrs.onSuccess || (() => void 0),
            onError: attrs.onError || (() => void 0)
          });
        }
      },
      this.$slots.default
    );
  }
});
const installInertiaLink = (app) => app.component("InertiaLink", InertiaLink);
if (typeof window !== "undefined" && window.Vue) {
  window.Vue.use(InertiaLink);
}

function useHeadManager() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$headManager;
  } else {
    warn();
  }
  return void 0;
}
function usePage() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$page;
  }
  return usePage$1();
}
function useInertia() {
  const instance = getCurrentInstance();
  if (instance) {
    return instance.proxy.$inertia;
  } else {
    warn();
  }
  return void 0;
}
function useForm(rememberKey, data) {
  const instance = getCurrentInstance();
  if (rememberKey) {
    return instance ? (
      // @ts-ignore
      instance.proxy.$inertia.form(rememberKey, data)
    ) : useForm$1(rememberKey, data);
  }
  return instance ? (
    // @ts-ignore
    instance.proxy.$inertia.form(data)
  ) : useForm$1(data);
}
function route(name, params, absolute, config) {
  const instance = getCurrentInstance();
  if (instance && instance.proxy.route) {
    return instance.proxy.route(name, params, absolute, config);
  }
  return ziggy(name, params, absolute, config);
}
const warn = () => console.warn(
  `[Inertia Composable] getCurrentInstance() returned null. Method must be called at the top of a setup() function.`
);
if (typeof window !== "undefined") {
  window.route = route;
}

export { InertiaLink, installInertiaLink as install, route, useForm, useHeadManager, useInertia, usePage };
